@@ -1,15 +1,15 @@
 from typing import Optional, Dict, Any
 
-from pyspark import keyword_only
 from pyspark.sql.dataframe import DataFrame
 
 from spark_pipeline_framework.progress_logger.progress_logger import ProgressLogger
 from spark_pipeline_framework.proxy_generator.python_proxy_base import PythonProxyBase
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 
 
 class FeatureCarrierPythonTransformer(PythonProxyBase):
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         name: Optional[str] = None,
