@@ -5,6 +5,7 @@ from typing import Any, Dict, List, Union, Optional
 from pyspark.ml.base import Transformer
 from pyspark.sql.dataframe import DataFrame
 
+from spark_pipeline_framework.logger.log_level import LogLevel
 from spark_pipeline_framework.logger.yarn_logger import get_logger
 from spark_pipeline_framework.progress_logger.progress_log_metric import (
     ProgressLogMetric,
@@ -22,7 +23,9 @@ class FrameworkPipeline(Transformer):
         self,
         parameters: Dict[str, Any],
         progress_logger: ProgressLogger,
+        run_id: Optional[str] = None,
         log_level: Optional[Union[int, str]] = None,
+        name: Optional[str] = None,
     ) -> None:
         """
         Base class for all pipelines
@@ -31,6 +34,7 @@ class FrameworkPipeline(Transformer):
         """
         super(FrameworkPipeline, self).__init__()
         self.transformers: List[Transformer] = []
+        self._run_id: Optional[str] = run_id
         self.steps: List[Union[Transformer, List[Transformer]]] = []
         self.__parameters: Dict[str, Any] = parameters
         self.progress_logger: ProgressLogger = progress_logger
@@ -38,6 +42,7 @@ class FrameworkPipeline(Transformer):
         self.log_level: Optional[Union[int, str]] = log_level or os.environ.get(
             "LOGLEVEL"
         )
+        self.name: Optional[str] = name
 
     @property
     def parameters(self) -> Dict[str, Any]:
@@ -55,9 +60,14 @@ class FrameworkPipeline(Transformer):
         logger = get_logger(__name__)
         count_of_transformers: int = len(self.transformers)
         i: int = 0
-        pipeline_name: str = self.__class__.__name__
+        pipeline_name: str = self.name or self.__class__.__name__
+
         self.progress_logger.log_event(
-            event_name=pipeline_name, event_text=f"Starting Pipeline {pipeline_name}"
+            event_name=pipeline_name,
+            event_text=f"Starting Pipeline {pipeline_name}" + f"_{self._run_id}"
+            if self._run_id
+            else "",
+            log_level=LogLevel.INFO,
         )
         for transformer in self.transformers:
             assert isinstance(transformer, Transformer), type(transformer)
@@ -126,7 +136,9 @@ class FrameworkPipeline(Transformer):
                     e.args = (f"In Stage ({stage_name})", *e.args)
                 raise e
         self.progress_logger.log_event(
-            event_name=pipeline_name, event_text=f"Finished Pipeline {pipeline_name}"
+            event_name=pipeline_name,
+            event_text=f"Finished Pipeline {pipeline_name}",
+            log_level=LogLevel.INFO,
         )
         return df
 
