@@ -1,6 +1,6 @@
 from typing import Any, Dict, Optional
 
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql import DataFrame
 from pyspark.sql.functions import from_json
@@ -20,7 +20,7 @@ from spark_pipeline_framework.transformers.framework_transformer.v1.framework_tr
 # move this class to SPF
 class FrameworkKafkaReader(FrameworkTransformer):
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         kafka_brokers: str,
