@@ -122,7 +122,8 @@ class FrameworkParquetLoader(FrameworkTransformer):
                     df.sql_ctx.read if not stream else df.sql_ctx.readStream
                 )
 
-                df_reader = df_reader.option("mode", self.getMode())
+                mode = self.getMode()
+                df_reader = df_reader.option("mode", mode)
 
                 if merge_schema is True:
                     final_df = (
